pub enum OnBootAttachConfig {
AttachToComponentMoniker(String),
AttachToComponentUrl(String),
// some variants omitted
}Variants
AttachToComponentMoniker(String)
Attach to an existing component by moniker. If a component doesn’t exist at that moniker, wait for it to appear and attach to it when it does.
AttachToComponentUrl(String)
Attach to an existing component by url. If the component doesn’t exist with the specified url, wait for it to appear and attach to it when it does.
Implementations
Sourceimpl OnBootAttachConfig
impl OnBootAttachConfig
pub fn ordinal(&self) -> u64
pub fn unknown_variant_for_testing() -> OnBootAttachConfig
pub fn is_unknown(&self) -> bool