SessionManagerRequest

Enum SessionManagerRequest 

pub enum SessionManagerRequest {
    Configure {
        payload: SessionConfigureRequest,
        responder: SessionManagerConfigureResponder,
    },
    Start {
        payload: SessionStartRequest,
        responder: SessionManagerStartResponder,
    },
    Stop {
        responder: SessionManagerStopResponder,
    },
    Reset {
        responder: SessionManagerResetResponder,
    },
    StartSession {
        payload: SessionManagerStartSessionRequest,
        responder: SessionManagerStartSessionResponder,
    },
    StopSession {
        payload: SessionManagerStopSessionRequest,
        responder: SessionManagerStopSessionResponder,
    },
    AbortSession {
        payload: SessionManagerAbortSessionRequest,
        responder: SessionManagerAbortSessionResponder,
    },
    Status {
        responder: SessionManagerStatusResponder,
    },
    StartSessionOnBoot {
        payload: SessionManagerStartSessionOnBootRequest,
        responder: SessionManagerStartSessionOnBootResponder,
    },
}

Variants



Configure

Set up and prepare to profile



Start

Begin profiling and optionally begin writing data to the configured socket



Stop

End the profiling session and write out data to the earlier configured socket if not already writing.



Reset

Clean up and unconfigure the profiler. Flushes the remaining data and closes the provided socket. Doesn’t return until all data has been successfully written.



StartSession

Starts a standalone profiling session. This session runs independently of the client connection and buffers data internally.



StopSession

Ends the profiling session and writes out the buffered data.



AbortSession

Aborts an ongoing trace session without saving results.



Status

Returns the active profiling sessions. Currently assuming 1 active max, but returns a vector for future-proofing.



StartSessionOnBoot

Configures an on-boot profiling session.

Implementations