pub struct SessionManagerStartSessionOnBootRequest {
pub config: Option<OnBootConfig>,
/* private fields */
}Fields
config: Option<OnBootConfig>Trait Implementations
Sourceimpl Clone for SessionManagerStartSessionOnBootRequest
impl Clone for SessionManagerStartSessionOnBootRequest
Sourcefn clone(&self) -> SessionManagerStartSessionOnBootRequest
fn clone(&self) -> SessionManagerStartSessionOnBootRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D> Decode<SessionManagerStartSessionOnBootRequest, D> for SessionManagerStartSessionOnBootRequestwhere
D: ResourceDialect,
impl<D> Decode<SessionManagerStartSessionOnBootRequest, D> for SessionManagerStartSessionOnBootRequestwhere
D: ResourceDialect,
Sourcefn new_empty() -> SessionManagerStartSessionOnBootRequest
fn new_empty() -> SessionManagerStartSessionOnBootRequest
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for SessionManagerStartSessionOnBootRequest
impl Default for SessionManagerStartSessionOnBootRequest
Sourcefn default() -> SessionManagerStartSessionOnBootRequest
fn default() -> SessionManagerStartSessionOnBootRequest
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<SessionManagerStartSessionOnBootRequest, D> for &SessionManagerStartSessionOnBootRequestwhere
D: ResourceDialect,
impl<D> Encode<SessionManagerStartSessionOnBootRequest, D> for &SessionManagerStartSessionOnBootRequestwhere
D: ResourceDialect,
Sourceimpl PartialEq for SessionManagerStartSessionOnBootRequest
impl PartialEq for SessionManagerStartSessionOnBootRequest
Sourcefn eq(&self, other: &SessionManagerStartSessionOnBootRequest) -> bool
fn eq(&self, other: &SessionManagerStartSessionOnBootRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for SessionManagerStartSessionOnBootRequest
impl TypeMarker for SessionManagerStartSessionOnBootRequest
Sourcetype Owned = SessionManagerStartSessionOnBootRequest
type Owned = SessionManagerStartSessionOnBootRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SessionManagerStartSessionOnBootRequest
impl ValueTypeMarker for SessionManagerStartSessionOnBootRequest
Sourcetype Borrowed<'a> = &'a SessionManagerStartSessionOnBootRequest
type Borrowed<'a> = &'a SessionManagerStartSessionOnBootRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SessionManagerStartSessionOnBootRequest as TypeMarker>::Owned,
) -> <SessionManagerStartSessionOnBootRequest as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SessionManagerStartSessionOnBootRequest as TypeMarker>::Owned, ) -> <SessionManagerStartSessionOnBootRequest as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for SessionManagerStartSessionOnBootRequest
impl StructuralPartialEq for SessionManagerStartSessionOnBootRequest