pub struct SessionManagerStatusResponse {
pub sessions: Option<Vec<ProfilerStatus>>,
/* private fields */
}Fields
sessions: Option<Vec<ProfilerStatus>>Trait Implementations
Sourceimpl Clone for SessionManagerStatusResponse
impl Clone for SessionManagerStatusResponse
Sourcefn clone(&self) -> SessionManagerStatusResponse
fn clone(&self) -> SessionManagerStatusResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionManagerStatusResponse
impl Debug for SessionManagerStatusResponse
Sourceimpl<D> Decode<SessionManagerStatusResponse, D> for SessionManagerStatusResponsewhere
D: ResourceDialect,
impl<D> Decode<SessionManagerStatusResponse, D> for SessionManagerStatusResponsewhere
D: ResourceDialect,
Sourcefn new_empty() -> SessionManagerStatusResponse
fn new_empty() -> SessionManagerStatusResponse
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for SessionManagerStatusResponse
impl Default for SessionManagerStatusResponse
Sourcefn default() -> SessionManagerStatusResponse
fn default() -> SessionManagerStatusResponse
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<SessionManagerStatusResponse, D> for &SessionManagerStatusResponsewhere
D: ResourceDialect,
impl<D> Encode<SessionManagerStatusResponse, D> for &SessionManagerStatusResponsewhere
D: ResourceDialect,
Sourceimpl PartialEq for SessionManagerStatusResponse
impl PartialEq for SessionManagerStatusResponse
Sourcefn eq(&self, other: &SessionManagerStatusResponse) -> bool
fn eq(&self, other: &SessionManagerStatusResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TypeMarker for SessionManagerStatusResponse
impl TypeMarker for SessionManagerStatusResponse
Sourcetype Owned = SessionManagerStatusResponse
type Owned = SessionManagerStatusResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SessionManagerStatusResponse
impl ValueTypeMarker for SessionManagerStatusResponse
Sourcetype Borrowed<'a> = &'a SessionManagerStatusResponse
type Borrowed<'a> = &'a SessionManagerStatusResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SessionManagerStatusResponse as TypeMarker>::Owned,
) -> <SessionManagerStatusResponse as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SessionManagerStatusResponse as TypeMarker>::Owned, ) -> <SessionManagerStatusResponse as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for SessionManagerStatusResponse
impl StructuralPartialEq for SessionManagerStatusResponse