pub struct SessionManagerStopResponder { /* private fields */ }Implementations
Sourceimpl SessionManagerStopResponder
impl SessionManagerStopResponder
Sourcepub fn send(self, payload: &SessionResult) -> Result<(), Error>
pub fn send(self, payload: &SessionResult) -> Result<(), Error>
Sends a response to the FIDL transaction.
Sets the channel to shutdown if an error occurs.
Sourcepub fn send_no_shutdown_on_err(
self,
payload: &SessionResult,
) -> Result<(), Error>
pub fn send_no_shutdown_on_err( self, payload: &SessionResult, ) -> Result<(), Error>
Similar to “send” but does not shutdown the channel if an error occurs.