pub struct SessionResult {
pub samples_collected: Option<u64>,
pub mean_sample_time: Option<u64>,
pub median_sample_time: Option<u64>,
pub min_sample_time: Option<u64>,
pub max_sample_time: Option<u64>,
pub missing_process_mappings: Option<Vec<u64>>,
/* private fields */
}Expand description
The result returned after stopping a profiling session.
Fields
samples_collected: Option<u64>mean_sample_time: Option<u64>median_sample_time: Option<u64>min_sample_time: Option<u64>max_sample_time: Option<u64>missing_process_mappings: Option<Vec<u64>>Trait Implementations
Sourceimpl Clone for SessionResult
impl Clone for SessionResult
Sourcefn clone(&self) -> SessionResult
fn clone(&self) -> SessionResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionResult
impl Debug for SessionResult
Sourceimpl<D> Decode<SessionResult, D> for SessionResultwhere
D: ResourceDialect,
impl<D> Decode<SessionResult, D> for SessionResultwhere
D: ResourceDialect,
Sourcefn new_empty() -> SessionResult
fn new_empty() -> SessionResult
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.Sourceimpl Default for SessionResult
impl Default for SessionResult
Sourcefn default() -> SessionResult
fn default() -> SessionResult
Returns the “default value” for a type. Read more
Sourceimpl<D> Encode<SessionResult, D> for &SessionResultwhere
D: ResourceDialect,
impl<D> Encode<SessionResult, D> for &SessionResultwhere
D: ResourceDialect,
Sourceimpl PartialEq for SessionResult
impl PartialEq for SessionResult
Sourceimpl TypeMarker for SessionResult
impl TypeMarker for SessionResult
Sourcetype Owned = SessionResult
type Owned = SessionResult
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SessionResult
impl ValueTypeMarker for SessionResult
Sourcetype Borrowed<'a> = &'a SessionResult
type Borrowed<'a> = &'a SessionResult
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreSourcefn borrow(
value: &<SessionResult as TypeMarker>::Owned,
) -> <SessionResult as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<SessionResult as TypeMarker>::Owned, ) -> <SessionResult as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.impl Persistable for SessionResult
impl StructuralPartialEq for SessionResult