pub enum SessionManagerRequest {
Configure {
payload: SessionConfigureRequest,
responder: SessionManagerConfigureResponder,
},
Start {
payload: SessionStartRequest,
responder: SessionManagerStartResponder,
},
Stop {
responder: SessionManagerStopResponder,
},
Reset {
responder: SessionManagerResetResponder,
},
StartSession {
payload: SessionManagerStartSessionRequest,
responder: SessionManagerStartSessionResponder,
},
StopSession {
payload: SessionManagerStopSessionRequest,
responder: SessionManagerStopSessionResponder,
},
AbortSession {
payload: SessionManagerAbortSessionRequest,
responder: SessionManagerAbortSessionResponder,
},
Status {
responder: SessionManagerStatusResponder,
},
StartSessionOnBoot {
payload: SessionManagerStartSessionOnBootRequest,
responder: SessionManagerStartSessionOnBootResponder,
},
}Variants
Configure
Set up and prepare to profile
Start
Begin profiling and optionally begin writing data to the configured socket
Stop
End the profiling session and write out data to the earlier configured socket if not already writing.
Fields
responder: SessionManagerStopResponderReset
Clean up and unconfigure the profiler. Flushes the remaining data and closes the provided socket. Doesn’t return until all data has been successfully written.
Fields
responder: SessionManagerResetResponderStartSession
Starts a standalone profiling session. This session runs independently of the client connection and buffers data internally.
StopSession
Ends the profiling session and writes out the buffered data.
AbortSession
Aborts an ongoing trace session without saving results.
Status
Returns the active profiling sessions. Currently assuming 1 active max, but returns a vector for future-proofing.
Fields
responder: SessionManagerStatusResponderStartSessionOnBoot
Configures an on-boot profiling session.
Fields
responder: SessionManagerStartSessionOnBootResponderImplementations
Sourceimpl SessionManagerRequest
impl SessionManagerRequest
pub fn into_configure( self, ) -> Option<(SessionConfigureRequest, SessionManagerConfigureResponder)>
pub fn into_start( self, ) -> Option<(SessionStartRequest, SessionManagerStartResponder)>
pub fn into_stop(self) -> Option<SessionManagerStopResponder>
pub fn into_reset(self) -> Option<SessionManagerResetResponder>
pub fn into_start_session( self, ) -> Option<(SessionManagerStartSessionRequest, SessionManagerStartSessionResponder)>
pub fn into_stop_session( self, ) -> Option<(SessionManagerStopSessionRequest, SessionManagerStopSessionResponder)>
pub fn into_abort_session( self, ) -> Option<(SessionManagerAbortSessionRequest, SessionManagerAbortSessionResponder)>
pub fn into_status(self) -> Option<SessionManagerStatusResponder>
pub fn into_start_session_on_boot( self, ) -> Option<(SessionManagerStartSessionOnBootRequest, SessionManagerStartSessionOnBootResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL