pub struct SessionManagerProxy { /* private fields */ }Implementations
Sourceimpl SessionManagerProxy
impl SessionManagerProxy
Sourcepub fn new(channel: AsyncChannel) -> Self
pub fn new(channel: AsyncChannel) -> Self
Create a new Proxy for fuchsia.cpu.profiler/SessionManager.
Sourcepub fn take_event_stream(&self) -> SessionManagerEventStream
pub fn take_event_stream(&self) -> SessionManagerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn configure(
&self,
payload: SessionConfigureRequest,
) -> QueryResponseFut<SessionConfigureResult, DefaultFuchsiaResourceDialect>
pub fn configure( &self, payload: SessionConfigureRequest, ) -> QueryResponseFut<SessionConfigureResult, DefaultFuchsiaResourceDialect>
Set up and prepare to profile
Sourcepub fn start(
&self,
payload: &SessionStartRequest,
) -> QueryResponseFut<SessionStartResult, DefaultFuchsiaResourceDialect>
pub fn start( &self, payload: &SessionStartRequest, ) -> QueryResponseFut<SessionStartResult, DefaultFuchsiaResourceDialect>
Begin profiling and optionally begin writing data to the configured socket
Sourcepub fn stop(
&self,
) -> QueryResponseFut<SessionResult, DefaultFuchsiaResourceDialect>
pub fn stop( &self, ) -> QueryResponseFut<SessionResult, DefaultFuchsiaResourceDialect>
End the profiling session and write out data to the earlier configured socket if not already writing.
Sourcepub fn reset(&self) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
pub fn reset(&self) -> QueryResponseFut<(), DefaultFuchsiaResourceDialect>
Clean up and unconfigure the profiler. Flushes the remaining data and closes the provided socket. Doesn’t return until all data has been successfully written.
Sourcepub fn start_session(
&self,
payload: SessionManagerStartSessionRequest,
) -> QueryResponseFut<SessionManagerStartSessionResult, DefaultFuchsiaResourceDialect>
pub fn start_session( &self, payload: SessionManagerStartSessionRequest, ) -> QueryResponseFut<SessionManagerStartSessionResult, DefaultFuchsiaResourceDialect>
Starts a standalone profiling session. This session runs independently of the client connection and buffers data internally.
Sourcepub fn stop_session(
&self,
payload: SessionManagerStopSessionRequest,
) -> QueryResponseFut<SessionManagerStopSessionResult, DefaultFuchsiaResourceDialect>
pub fn stop_session( &self, payload: SessionManagerStopSessionRequest, ) -> QueryResponseFut<SessionManagerStopSessionResult, DefaultFuchsiaResourceDialect>
Ends the profiling session and writes out the buffered data.
Sourcepub fn abort_session(
&self,
payload: &SessionManagerAbortSessionRequest,
) -> QueryResponseFut<SessionManagerAbortSessionResult, DefaultFuchsiaResourceDialect>
pub fn abort_session( &self, payload: &SessionManagerAbortSessionRequest, ) -> QueryResponseFut<SessionManagerAbortSessionResult, DefaultFuchsiaResourceDialect>
Aborts an ongoing trace session without saving results.
Sourcepub fn status(
&self,
) -> QueryResponseFut<SessionManagerStatusResult, DefaultFuchsiaResourceDialect>
pub fn status( &self, ) -> QueryResponseFut<SessionManagerStatusResult, DefaultFuchsiaResourceDialect>
Returns the active profiling sessions. Currently assuming 1 active max, but returns a vector for future-proofing.
Sourcepub fn start_session_on_boot(
&self,
payload: &SessionManagerStartSessionOnBootRequest,
) -> QueryResponseFut<SessionManagerStartSessionOnBootResult, DefaultFuchsiaResourceDialect>
pub fn start_session_on_boot( &self, payload: &SessionManagerStartSessionOnBootRequest, ) -> QueryResponseFut<SessionManagerStartSessionOnBootResult, DefaultFuchsiaResourceDialect>
Configures an on-boot profiling session.